@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -41,7 +41,6 @@
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
-#include <assert.h>
 #include "rx.h"
 #include "rx_clock.h"
 #endif
@@ -74,10 +73,8 @@ clock_Sync(void)
 
     signal(SIGALRM, SIG_IGN);
     if (setitimer(ITIMER_REAL, &itimer, &otimer) != 0) {
-	fprintf(stderr, "clock:  could not set interval timer; \
-				aborted(errno=%d)\n", errno);
-	fflush(stderr);
-	assert(0);
+	osi_Panic("clock:  could not set interval timer; aborted(errno=%d)\n",
+                  errno);
     }
     if (relclock_epoch.usec + startvalue.usec >= otimer.it_value.tv_usec) {
 	relclock_epoch.sec = relclock_epoch.sec +
